//
//  NBContentsRequest.h
//  NswBaaSSDK
//
//  Copyright (C) 2014 NIPPON SYSTEMWARE CO.,LTD. All rights reserved.
//

#import <Foundation/Foundation.h>

/**
 * コンテンツの種別フラグ 【SDKバージョン2.0.0以降】
 */
typedef NS_ENUM(NSInteger, NBContentTimingFlag) {
    /** 通常コンテンツ */
    kNBContentTimingFlagNormal = 0x0001,
    
    /** 位置連動コンテンツ */
    kNBContentTimingFlagLandmark = 0x0002,
    
    /** 周辺機器連動コンテンツ */
    kNBContentTimingFlagBeacon= 0x0004
};

/**
 * コンテンツの有効期限フラグ 【SDKバージョン2.0.0以降】
 */
typedef NS_ENUM(NSInteger, NBContentTermFlag) {
    /** 有効期限内のコンテンツ */
    kNBContentTermFlagIn = 0x0001,
    
    /** 有効期限前のコンテンツ */
    kNBContentTermFlagBefore = 0x0002,
    
    /** 有効期限後のコンテンツ */
    kNBContentTermFlagAfter = 0x0004
};


/**
 * コンテンツのタイプフラグ 【SDKバージョン2.0.0以降】
 */
typedef NS_ENUM(NSInteger, NBContentTypeFlag) {
    /** クーポン */
    kNBContentTypeFlagCoupon = 0x0001,
    
    /** お知らせ */
    kNBContentTypeFlagInfo = 0x0002,
    
    /** チラシ */
    kNBContentTypeFlagFlyer = 0x0004
};

/**
 * コンテンツ取得条件指定クラス 【SDKバージョン2.0.0以降】
 */
@interface NBContentsRequest : NSObject

/**
 * コンテンツID
 *
 * 取得するコンテンツのIDを限定する
 *
 * [初期値："" - 限定しない]
 */
@property (nonatomic) NSString *contentId;

/**
 * 取得するコンテンツの配信契機を限定する
 *
 * NBContentTimingFlagの中から限定するものの論理和を指定する
 *
 * [初期値：kNBContentTimingFlagNormal - 通常コンテンツのみ取得]
 */
@property (nonatomic) NBContentTimingFlag pubTiming;

/**
 * 使用上限回数以上、使用したコンテンツを取得するかどうか
 *
 * [初期値：NO - 使用上限回数以上、使用されたコンテンツは取得しない]
 */
@property (nonatomic) BOOL isOverLimitOn;

/**
 * タグで取得するコンテンツを限定する
 *
 * ※NBContentのtagの中に、指定した文字列が『含まれている』コンテンツのみを取得
 *
 * [初期値："" - 限定しない]
 */
@property (nonatomic) NSString *tag;

/**
 * 取得するコンテンツを、指定したランドマークIDと関連づいているものに限定する
 *
 * [初期値："" - 限定しない]
 */
@property (nonatomic) NSString *relatedLandmarkId;

/**
 * 取得するコンテンツの有効期限の条件を限定する
 *
 * NBContentTermFlagの中から限定するものの論理和を指定する
 *
 * [初期値：kNBContentTermFlagIn - 有効期限内のコンテンツのみ取得]
 */
@property (nonatomic) NBContentTermFlag validTerm;

/**
 * 無効コンテンツを取得するかどうか
 *
 * [初期値：NO - 無効コンテンツを取得しない]
 */
@property (nonatomic) BOOL isDisableOn;

/**
 * 一時無効コンテンツを取得するかどうか
 *
 * [初期値：NO - 一時無効コンテンツを取得しない]
 */
@property (nonatomic) BOOL isTmpDisableOn;

/**
 * 取得するコンテンツのタイプを限定する
 *
 * NBContentTypeFlagの中から限定するものの論理和を指定する
 *
 * [初期値：kNBContentTypeFlagCoupon | kNBContentTypeFlagFlyer | kNBContentTypeFlagInfo - クーポン・お知らせ・チラシを取得する]
 */
@property (nonatomic) NBContentTypeFlag contentType;

/**
 * 取得するコンテンツのタイプを限定する。[拡張コンテンツタイプ用]<font color="red">【SDKバージョン3.2.0以降】</font><br>
 *
 * 初期値以外の数字を入れた場合、NBContentTypeFlagでの指定は無効となる。<br>
 *
 * [初期値：-1 - 拡張コンテンツを取得しない]
 */
@property (nonatomic) int customContentLimit;

/**
 * 限定しているコンテンツのタイプを取得する。[拡張コンテンツタイプ用]<font color="red">【SDKバージョン3.2.0以降】</font><br>
 * @return
 */
- (int)getCustomContentType;

/**
 * 拡張コンテンツのタイプ　[拡張コンテンツタイプ用]<font color="red">【SDKバージョン3.2.0以降】</font><br>
 * @return
 */
@property (nonatomic) int customContentType;

@end
