//
//  ViewController.m
//  SampleApp
//

#import "ViewController.h"
#import <NswBaaSSDK/NBNswBaaSManager.h>

@interface ViewController () <NBBeaconManagerDelegate>

@property NBBeaconManager *beaconManager;
@property CLBeaconRegion *region1;
@property CLBeaconRegion *region2;

@end

@implementation ViewController

- (void)viewDidLoad
{
    [super viewDidLoad];
    
    //ポスモバWebで登録したビーコンのUUIDをご使用ください
    NSUUID *uuid1 = [[NSUUID alloc] initWithUUIDString:@"00000000-0000-0000-0000-000000000001"];
    NSUUID *uuid2 = [[NSUUID alloc] initWithUUIDString:@"00000000-0000-0000-0000-000000000002"];
    
    //CLBeaconRegionのidentifierはアプリで一意になるように決めてください
    self.region1 = [[CLBeaconRegion alloc] initWithProximityUUID:uuid1 identifier:@"region1"];
    self.region2 = [[CLBeaconRegion alloc] initWithProximityUUID:uuid2 major:1 minor:1 identifier:@"region2"];
    self.beaconManager = [[NBNswBaaSManager sharedManager] sharedBeaconManager];
    if (!self.beaconManager) {
        NSLog(@"ビーコン検出機能が使用できない端末です");
    } else {
        self.beaconManager.delegate = self;
    }
}

- (void)viewDidAppear:(BOOL)animated
{
    [super viewDidAppear:animated];
    
    NBBeaconStartResult result = [self.beaconManager startBeaconSearchInRegion:self.region1];
    if (result == kNBBeaconStartResultSuccess) {
        [self.beaconManager startMonitoringForBeacon:self.region1];
        [self.beaconManager startBeaconSearchInRegion:self.region2];
        [self.beaconManager startMonitoringForBeacon:self.region2];
    } else {
        if (result == kNBBeaconStartResultFailedBluetoothOff) {
            NSLog(@"Bluetooth設定をONにして再度お試しください");
        } else {
            NSLog(@"ビーコン検出機能の開始に失敗しました");
        }
    }
}

- (void)viewDidDisappear:(BOOL)animated
{
    [super viewDidDisappear:animated];
    
    [self.beaconManager stopMonitoringForBeacon:self.region1];
    [self.beaconManager stopBeaconSearchInRegion:self.region1];
    //region2はバックグラウンドでも検知を続けさせるために、stopしません。
}

#pragma mark - NBBeaconManagerDelegate

/**
 * ビーコン検出範囲内に入ったときに呼び出される
 *
 * @param region startMonitoringForBeacon:メソッドで指定したCLBeaconRegionインスタンス
 *
 * @param beacon ビーコン
 *
 * @see [NBBeaconManager delegate]
 */
- (void)didEnterBeaconRegion:(CLBeaconRegion *)region beacon:(NBBeacon *)beacon
{
    NSLog(@"ビーコン検出範囲に入った %@", beacon);
}

/**
 * ビーコン検出範囲内から出たときに呼び出される
 *
 * @param region startMonitoringForBeacon:メソッドで指定したCLBeaconRegionインスタンス
 *
 * @param beacon ビーコン
 *
 * @see [NBBeaconManager delegate]
 */
- (void)didExitBeaconRegion:(CLBeaconRegion *)region beacon:(NBBeacon *)beacon
{
    NSLog(@"ビーコン検出範囲から出た %@", beacon);
}

/**
 * ビーコン連動コンテンツが見つかったときに呼び出される
 *
 * @param beacon ビーコン
 *
 * @param content コンテンツ
 *
 * @see [NBBeaconManager delegate]
 */
- (void)didFindContent:(NBBeacon *)beacon content:(NBContent *)content
{
    NSLog(@"検出したビーコンに関連したコンテンツが見つかった %@", content);
}

/**
 * 検出しているビーコンに対して頻繁(約1秒ごと)に呼び出される。
 *
 * NBBeaconクラスのproximityプロパティに現在のビーコンとの大まかな距離が設定されている。
 *
 * 本メソッド以外で取得されたNBBeaconクラスのproximityプロパティは不正確のため、距離を取得したい場合は本メソッドを使用すること。
 *
 * @param beacons ビーコン
 *
 * @param region startMonitoringForBeacon:メソッドで指定したCLBeaconRegionインスタンス
 *
 * @see [NBBeaconManager delegate]
 */
- (void)didRangeBeacons:(NSArray *)beacons inRegion:(CLBeaconRegion *)region
{
    //複数のCLBeaconRegionでstartBeaconSearchInRegion:を実行した場合、
    //それぞれのCLBeaconRegionで検出可能なビーコンについてこのメソッドがコールされます
    NSLog(@"検出中のビーコン %@ %@", region.identifier, beacons);
}

@end
